@@ -3,5 +3,6 @@
                     fields="Version")
   packageStartupMessage(paste(pkgname, RFver))
   packageStartupMessage("Convenience Functions for Multivariate MCMC Using Univariate Samplers")
-  packageStartupMessage("Scientific Computing Group, Sentrana Inc. &\nHeart and Lung Institute, Imperial College London")
+  packageStartupMessage("For citations, please use:")
+  packageStartupMessage("Alireza S. Mahani, Mansour T. A. Sharabiani (2017). Multivariate-From-Univariate MCMC Sampler: The R Package MfUSampler. Journal of Statistical Software, Code Snippets, 78(1), 1-22. doi:10.18637/jss.v078.c01")
 }
